@@ -1,11 +1,11 @@
 use super::util::Scope;
 use std::{cell::RefCell, rc::Rc};
 use swc_atoms::{js_word, JsWord};
-use swc_common::{collections::AHashSet, DUMMY_SP};
+use swc_common::collections::AHashSet;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::enable_helper;
 use swc_ecma_visit::{
-    as_folder, noop_visit_mut_type, noop_visit_type, Fold, Node, Visit, VisitMut, VisitWith,
+    as_folder, noop_visit_mut_type, noop_visit_type, Fold, Visit, VisitMut, VisitWith,
 };
 
 pub fn import_analyzer(scope: Rc<RefCell<Scope>>) -> impl Fold + VisitMut {
@@ -25,7 +25,7 @@ impl VisitMut for ImportAnalyzer {
     noop_visit_mut_type!();
 
     fn visit_mut_module(&mut self, module: &mut Module) {
-        self.visit_module(&*module, &Invalid { span: DUMMY_SP } as _);
+        self.visit_module(&*module);
 
         for (_, ty) in self.scope.borrow().import_types.iter() {
             if *ty {
@@ -50,7 +50,7 @@ impl VisitMut for ImportAnalyzer {
 impl Visit for ImportAnalyzer {
     noop_visit_type!();
 
-    fn visit_call_expr(&mut self, n: &CallExpr, _parent: &dyn Node) {
+    fn visit_call_expr(&mut self, n: &CallExpr) {
         n.visit_children_with(self);
         let mut scope = self.scope.borrow_mut();
         match &n.callee {
@@ -76,7 +76,7 @@ impl Visit for ImportAnalyzer {
         }
     }
 
-    fn visit_export_all(&mut self, export: &ExportAll, _parent: &dyn Node) {
+    fn visit_export_all(&mut self, export: &ExportAll) {
         *self
             .scope
             .borrow_mut()
@@ -85,7 +85,7 @@ impl Visit for ImportAnalyzer {
             .or_default() = true
     }
 
-    fn visit_import_decl(&mut self, import: &ImportDecl, _parent: &dyn Node) {
+    fn visit_import_decl(&mut self, import: &ImportDecl) {
         let mut scope = self.scope.borrow_mut();
         if import.specifiers.is_empty() {
             // import 'foo';
@@ -150,7 +150,7 @@ impl Visit for ImportAnalyzer {
         }
     }
 
-    fn visit_named_export(&mut self, export: &NamedExport, _parent: &dyn Node) {
+    fn visit_named_export(&mut self, export: &NamedExport) {
         if export.specifiers.iter().any(|v| match v {
             ExportSpecifier::Namespace(..) => true,
             _ => false,
